@@ -108,8 +108,8 @@ typedef enum
                                   @"Chiron", @"Pholus", @"Ceres", @"Pallas", @"Juno", @"Vesta", nil]
 
 /* notifications */
-#define AstroPrefsCallToAddItemsNotification	@"AstroPrefsCallToAddItems"	// modules should add their panes
-#define AstroPrefsAddItemNotification		@"AstroPrefsAddItem"		// we have to add a new menu item
+#define AstroPrefsCallToAddItemsNotification    @"AstroPrefsCallToAddItems"	// modules should add their panes
+#define AstroPrefsAddItemNotification           @"AstroPrefsAddItem"		// we have to add a new item
 
 @interface AstroController:NSObject <PreferencesMethods>
 {
