@@ -1,10 +1,10 @@
 /* AstroDate.m
  *
- * Copyright (C) 2006 by vhf interservice GmbH
+ * Copyright (C) 2006-2011 by Georg Fleischmann
  * Author:   Georg Fleischmann
  *
  * created:  2006-01-15
- * modified: 2006-12-18
+ * modified: 2011-07-11 (indexOfDateFormatForString(): check number of digits more tolerant)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -41,6 +41,7 @@ static AstroDate	*sharedInstance = nil;
 #define DATE3_STRING	NSLocalizedStringFromTableInBundle(@"DD MON YYYY HH:MM ZON", @"Astro", ASTRO_BUNDLE, NULL)
 #define ASTRO_DATEFORMATS	[NSArray arrayWithObjects: @"%d.%m.%Y", @"%Y-%m-%d", @"%d %b %Y", nil]
 #define ASTRO_DATEMASKS		[NSArray arrayWithObjects: @"99.99.9999", @"9999-99-99", @"99 AAA 9999", nil]
+#define ASTRO_DATESEPS      [NSArray arrayWithObjects: @".",          @"-",          @" ",           nil]
 #define ASTRO_DATEERRORS	[NSArray arrayWithObjects: DATE1_STRING, DATE2_STRING, DATE3_STRING, nil]
 
 
@@ -74,6 +75,7 @@ NSString *astroDateFormatForString(NSString *dateString)
     [super init];
     dateFormats = [ASTRO_DATEFORMATS retain];
     dateMasks   = [ASTRO_DATEMASKS   retain];
+    dateSeps    = [ASTRO_DATESEPS    retain];
     dateErrors  = [ASTRO_DATEERRORS  retain];
     monDict     = [[NSDictionary dictionaryWithObjectsAndKeys:
                    @"1", @"Jan",
@@ -97,19 +99,23 @@ NSString *astroDateFormatForString(NSString *dateString)
 
 - (NSString*)dateFormat	{ return Prefs_DateFormat; }
 
+/* retun date mask fitting to date
+ */
 - (int)indexOfDateFormatForString:(NSString*)dateString
-{   int		i, j;
-    BOOL	checkPrefix = YES;
+{   int     i, j, j1;
+    BOOL    checkPrefix = YES;
 
     for (i=0; i<[dateMasks count]; i++)
-    {   NSString	*dateMask = [dateMasks objectAtIndex:i];
+    {   NSString        *dateMask = [dateMasks objectAtIndex:i];
+        unsigned char   sep = [[dateSeps objectAtIndex:i] characterAtIndex:0];
 
         if ( (checkPrefix && [dateString length] >= [dateMask length]) ||
              [dateString length] == [dateMask length] )
-        {   BOOL	ok = NO;
+        {   BOOL    ok = NO;
+            int     compCnt = 0;    // component, either 0, 1, or 2
 
-            for (j=0; j<[dateMask length]; j++)	// test chars
-            {   unsigned char	c = [dateString characterAtIndex:j];
+            for (j=0, j1=0; j<[dateMask length]; j++, j1++) // test chars, FIXME: Min(dateMask, dateString)
+            {   unsigned char	c = [dateString characterAtIndex:j1];
                 unsigned char	m = [dateMask   characterAtIndex:j];
 
                 ok = NO;
@@ -118,14 +124,20 @@ NSString *astroDateFormatForString(NSString *dateString)
                     case '9':
                         if (isdigit(c))
                             ok = YES;
+                        else if ( checkPrefix && c == ' ' && compCnt == 2 )
+                            return i;       // last component and we reached the hour
+                        else if ( c == sep )
+                            ok = YES, j1--; // digit missing before seperator
                         break;
-                    case 'A':
+                    case 'A':               // month in "99 AAA 9999" format
                         if (isalpha(c))
                             ok = YES;
                         break;
                     default:
-                        if (m == c)
-                            ok = YES;
+                        if (m == c)         // '.', '-', ' '
+                        {   ok = YES;
+                            compCnt++;      // 0, 1, 2: day, month, or year component
+                        }
                 }
                 if (!ok)
                     break;
