@@ -1,11 +1,11 @@
 /* AstroPrincipal.h
  * Cenon Application additions for Astrology module
  *
- * Copyright (C) 2003-2006 by vhf interservice GmbH
+ * Copyright (C) 2003-2009 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  2003-03-28 (extracted from App.h)
- * modified: 2006-05-13
+ * modified: 2009-03-05 (Astro_Principal easier)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -37,7 +37,7 @@
 #include "TimeZoneManager.h"
 
 /* get principal */
-#define Astro_Principal [[[NSBundle bundleForClass:[AstroPrincipal class]] principalClass] instance]
+#define Astro_Principal [[AstroPrincipal class] instance]   //[[[NSBundle bundleForClass:[AstroPrincipal class]] principalClass] instance]
 
 /* notifications */
 #define CalculateChartNotification	@"AstroCalculateChart"	// we have to calculate a chart with the given data
