@@ -1312,11 +1312,12 @@ NSPoint computeAzimut(float lat, float lon, float deg0, MapSet *ms)
  */
 - (void) drawGraticule:(long)offsetESec :(long)offsetNSec
                       :(long)clipWSec :(long)clipNSec :(long)clipESec :(long)clipSSec :(SegList*)seglist
-{   struct pr_pos	*ptlist = seglist->ptlist;
-    unsigned char	*mvlist = seglist->mvlist;
-    long		spacing, y_inc, ux0, ux1, uy; // x0, x1, y;
-    int 		nPts = 0, outlineOnly = (ms->gridLines == 0);
-    float		xf = 0.0, yf = 0.0, x0f = 0.0, x1f = 0.0;
+{   struct pr_pos   *ptlist = seglist->ptlist;
+    unsigned char   *mvlist = seglist->mvlist;
+    long            spacing, y_inc, ux0, ux1, uy; // x0, x1, y;
+    int             nPts = 0, outlineOnly = (ms->gridLines == 0);
+    float           xf = 0.0, yf = 0.0, x0f = 0.0, x1f = 0.0;
+    float           width = 0.5;
 
     seglist->op = 10; // grid -> lightGray
 
@@ -1351,22 +1352,22 @@ NSPoint computeAzimut(float lat, float lon, float deg0, MapSet *ms)
     }
 
     if (ms->proj)
-	y_inc = DEG_TO_SEC(1);			// smaller vertical increment
+        y_inc = DEG_TO_SEC(1);			// smaller vertical increment
     else
     {
-	x0f = SEC_TO_DOTS(ms,clipWSec + offsetESec);	// constant parallel length
-	x1f = SEC_TO_DOTS(ms,clipESec + offsetESec);
+        x0f = SEC_TO_DOTS(ms,clipWSec + offsetESec);	// constant parallel length
+        x1f = SEC_TO_DOTS(ms,clipESec + offsetESec);
     }
 
     for (uy = clipSSec - (clipSSec % spacing); uy < clipNSec; uy += spacing)
     {
-	/* draw parallel at uy */
-	if (outlineOnly && uy > -DEG90_SECS && uy < DEG90_SECS)
+        /* draw parallel at uy */
+        if (outlineOnly && uy > -DEG90_SECS && uy < DEG90_SECS)
             continue;	// top/bottom only
-	if (nPts+2 > seglist->maxpoints)
+        if (nPts+2 > seglist->maxpoints)
         {   [self addSegments:seglist :nPts];
-	    nPts = 0;
-	}
+            nPts = 0;
+        }
         if (ms->proj == PROJ_AZIMUT) // circle around 0, 90 with radius lat uy
         {   NSPoint	p, center;
             float	rad;
@@ -1382,30 +1383,31 @@ NSPoint computeAzimut(float lat, float lon, float deg0, MapSet *ms)
             [arc setBegAngle:SEC_TO_DEG(clipWSec + offsetESec)];	// start angle West
             [arc setAngle:SEC_TO_DEG(clipESec - clipWSec)];
             [arc setColor:[NSColor colorWithCalibratedWhite:0.6 alpha:1.0]];
+            [arc setWidth:width];
             [[listDict objectForKey:@"Grid"] addObject:arc];
         }
         else if (ms->proj == PROJ_MERCATOR)
         {   int	uyn;
-	    x0f = SEC_TO_DOTS(ms, clipWSec + offsetESec);
-	    x1f = SEC_TO_DOTS(ms, clipESec + offsetESec);
+            x0f = SEC_TO_DOTS(ms, clipWSec + offsetESec);
+            x1f = SEC_TO_DOTS(ms, clipESec + offsetESec);
             uyn = computeMercatorY(uy);
             yf = SEC_TO_DOTS(ms, offsetNSec - uyn);
         }
         else if (!ms->proj)
             yf = SEC_TO_DOTS(ms, offsetNSec - uy);
-	else // if (ms->proj && ms->proj != PROJ_MERCATOR) 	// projection
-	{   int xp = XPROJ_SEC(XProj, abs(uy));
-	    ux0 = XPROJ_MUL(clipWSec, xp);
-	    ux1 = XPROJ_MUL(clipESec, xp);
-	    x0f = SEC_TO_DOTS(ms,ux0 + offsetESec);
-	    x1f = SEC_TO_DOTS(ms,ux1 + offsetESec);
-	}
-	ptlist[nPts].x = x0f;
-	ptlist[nPts].y = yf;
-	mvlist[nPts++] = 1;
-	ptlist[nPts].x = x1f;
-	ptlist[nPts].y = yf;
-	mvlist[nPts++] = 0;
+        else // if (ms->proj && ms->proj != PROJ_MERCATOR) 	// projection
+        {   int xp = XPROJ_SEC(XProj, abs(uy));
+            ux0 = XPROJ_MUL(clipWSec, xp);
+            ux1 = XPROJ_MUL(clipESec, xp);
+            x0f = SEC_TO_DOTS(ms,ux0 + offsetESec);
+            x1f = SEC_TO_DOTS(ms,ux1 + offsetESec);
+        }
+        ptlist[nPts].x = x0f;
+        ptlist[nPts].y = yf;
+        mvlist[nPts++] = 1;
+        ptlist[nPts].x = x1f;
+        ptlist[nPts].y = yf;
+        mvlist[nPts++] = 0;
     }
 
     /* draw N-S meridians */
@@ -1415,11 +1417,11 @@ NSPoint computeAzimut(float lat, float lon, float deg0, MapSet *ms)
         //if ( !(ms->proj == PROJ_AZIMUT && (!ux0 || ux0==324000 || ux0==648000 || ux0==-75600)) )
         //    continue;
 
-	/* draw meridian at ux0 */
-	if (outlineOnly && ux0 > -DEG180_SECS && ux0 < DEG180_SECS)
+        /* draw meridian at ux0 */
+        if (outlineOnly && ux0 > -DEG180_SECS && ux0 < DEG180_SECS)
             continue;		// left/right only
-	if (!ms->proj || ms->proj == PROJ_MERCATOR)
-	{   float	y0f, y1f;
+        if (!ms->proj || ms->proj == PROJ_MERCATOR)
+        {   float	y0f, y1f;
 
             xf = SEC_TO_DOTS(ms, ux0 + offsetESec - (ms->cntrLngSec % spacing));
             y0f = SEC_TO_DOTS(ms, offsetNSec - computeMercatorY(clipNSec));
@@ -1431,7 +1433,7 @@ NSPoint computeAzimut(float lat, float lon, float deg0, MapSet *ms)
             ptlist[nPts].y = y1f;
             mvlist[nPts++] = 0;
         }
-	else
+        else
             for (uy = clipSSec - (clipSSec % spacing); ;uy += y_inc)
             {
                 /* draw meridian segment above uy */
@@ -2244,12 +2246,12 @@ int map_setup(MapSet *ms, int width, int height)
  */
 
 - (void)addSegments:(SegList*)seglist :(int)ptCount
-{   int 		i, ptcnt;
-    float		width = 0.0;
-    NSPoint		p0 = {0.0, 0.0};
-    NSColor		*col = [NSColor blackColor];
-    VPolyLine		*polyLine = nil;
-    NSMutableArray	*list = nil;
+{   int             i, ptcnt;
+    float           width = 0.5;
+    NSPoint         p0 = {0.0, 0.0};
+    NSColor         *col = [NSColor blackColor];
+    VPolyLine       *polyLine = nil;
+    NSMutableArray  *list = nil;
 
     switch ( seglist->op )
     {
