@@ -1,11 +1,11 @@
 /* astroCommon.h
  * Common astronomical functions
  *
- * Copyright (C) 1998-2009 by vhf interservice GmbH
+ * Copyright (C) 1998-2012 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  1998-11-06
- * modified: 2009-04-08
+ * modified: 2011-03-21 (vhfJDFromNSDate)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -29,6 +29,8 @@
 #ifndef VHF_H_ASTROCOMMON
 #define VHF_H_ASTROCOMMON
 
+#include <VHFShared/vhfCompatibility.h>     // CGFloat for OS X 10.4
+
 float sunNode(int year);
 
 NSMutableData* reducedTable(NSData *tableData, int tableSize, double factor);
@@ -49,7 +51,7 @@ double harmonicValue(double deg);
 NSString *stringFromDeg(float deg);
 float degFromString(NSString *degString);
 
-int sortAsNumbers(id str1, id str2, void *context);
+NSInteger sortAsNumbers(id str1, id str2, void *context);
 
 float frac(float x);
 
@@ -58,10 +60,12 @@ double vhfMJD(NSCalendarDate *date);
 double vhfSideralTimeMJD(double mjd, float lon);
 
 /* Julian Day (reference = -4712, compatible to swiss ephemeris) */
+double vhfJDFromNSDate(NSDate *date);
 double vhfJulianDay(NSCalendarDate *date);
 double vhfJulianDayFromInt(int yyyymmdd, int hhmm);
 //double vhfJulianDayFromNSDate(NSCalendarDate *date);
 int vhfIntDateFromJulianDay(double jd, int *yymmdd, int *hhmm);
+NSCalendarDate *vhfNSDateFromJD(double jd);
 double vhfSideralTime(double jd, float lon);	// sideral time in hours
 
 /* calculate astronomical values with sideral time [hours] (or better seconds and integer ???) */
